# Generated by roxygen2: do not edit by hand

S3method("$",gtregression)
S3method(print,gtregression)
S3method(print,gtregression_forest)
S3method(print,gtregression_reg_check)
S3method(print,identify_confounder_result)
S3method(print,merged_table)
export(check_collinearity)
export(check_convergence)
export(check_ph)
export(compare_models)
export(cox_reg)
export(descriptive_table)
export(dissect)
export(forest_df)
export(forest_reg)
export(gtregression_app)
export(identify_confounder)
export(interaction_models)
export(km_plot)
export(km_risk_table)
export(logrank_test)
export(mediation_analysis)
export(merge_tables)
export(modify_table)
export(multi_reg)
export(plot_mediation)
export(plot_model_fit)
export(plot_reg)
export(plot_reg_combine)
export(plot_surv_fit)
export(rmst_table)
export(save_docx)
export(save_forest)
export(save_plot)
export(save_table)
export(select_models)
export(stratified_multi_reg)
export(stratified_uni_reg)
export(surv_model_compare)
export(surv_predict)
export(surv_reg)
export(survival_prob)
export(survival_quantiles)
export(survival_summary)
export(uni_reg)
importFrom(MASS,glm.nb)
importFrom(broom,tidy)
importFrom(broom.helpers,tidy_add_reference_rows)
importFrom(broom.helpers,tidy_plus_plus)
importFrom(dplyr,bind_rows)
importFrom(dplyr,case_when)
importFrom(dplyr,filter)
importFrom(dplyr,mutate)
importFrom(flextable,body_add_flextable)
importFrom(forestploter,forest)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_cartesian)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_ribbon)
importFrom(ggplot2,geom_step)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggsave)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_linetype_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,theme_classic)
importFrom(ggplot2,theme_light)
importFrom(ggplot2,theme_minimal)
importFrom(ggplot2,theme_void)
importFrom(grid,convertHeight)
importFrom(grid,convertWidth)
importFrom(grid,grid.draw)
importFrom(grid,grid.newpage)
importFrom(grid,popViewport)
importFrom(grid,pushViewport)
importFrom(grid,unit)
importFrom(grid,viewport)
importFrom(officer,body_add_gg)
importFrom(officer,body_add_par)
importFrom(officer,read_docx)
importFrom(patchwork,wrap_plots)
importFrom(purrr,map)
importFrom(rlang,.data)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,anova)
importFrom(stats,as.formula)
importFrom(stats,ave)
importFrom(stats,binomial)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,cooks.distance)
importFrom(stats,cor)
importFrom(stats,delete.response)
importFrom(stats,deviance)
importFrom(stats,glm)
importFrom(stats,glm.control)
importFrom(stats,lm)
importFrom(stats,logLik)
importFrom(stats,median)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,na.omit)
importFrom(stats,nobs)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,poisson)
importFrom(stats,predict)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,reformulate)
importFrom(stats,residuals)
importFrom(stats,setNames)
importFrom(stats,shapiro.test)
importFrom(stats,terms)
importFrom(survival,Surv)
importFrom(survival,cox.zph)
importFrom(survival,coxph)
importFrom(survival,survdiff)
importFrom(survival,survfit)
importFrom(survival,survreg)
importFrom(tibble,tibble)
importFrom(utils,data)
importFrom(utils,globalVariables)
importFrom(utils,head)
