% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/footnotes.R
\name{.footnotes_multi_strata}
\alias{.footnotes_multi_strata}
\title{Compose footnotes for multivariable strata (abbrev + per-stratum N)}
\usage{
.footnotes_multi_strata(approach, fits_by_stratum, stratifier)
}
\description{
Compose footnotes for multivariable strata (abbrev + per-stratum N)
}
\keyword{internal}
