% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/reg_check_print.R
\name{print.gtregression_reg_check}
\alias{print.gtregression_reg_check}
\title{Print linear-regression diagnostics as a publication-ready table}
\usage{
\method{print}{gtregression_reg_check}(x, ...)
}
\arguments{
\item{x}{A diagnostic list stored in a gtregression regression result.}

\item{...}{Unused.}
}
\value{
The diagnostic object, invisibly.
}
\description{
Print linear-regression diagnostics as a publication-ready table
}
\keyword{internal}
