% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_mediation.R
\name{plot_mediation}
\alias{plot_mediation}
\title{Plot mediation paths}
\usage{
plot_mediation(mediation_object, show_estimates = TRUE, base_size = 13)
}
\arguments{
\item{mediation_object}{Object returned by \code{mediation_analysis()}.}

\item{show_estimates}{Logical; if \code{TRUE}, show direct and indirect
effect estimates on the plot.}

\item{base_size}{Base font size.}
}
\value{
A \code{ggplot2} object.
}
\description{
Draw the exposure, mediator, and outcome path from a
\code{mediation_analysis()} result.
}
\examples{
med <- mediation_analysis(
  data = data_diabetes_mediation,
  exposure = obesity,
  mediator = glucose,
  outcome = diabetes,
  covariates = c(age, blood_pressure, pregnancies, diabetes_pedigree),
  outcome_approach = logit,
  sims = 50,
  seed = 123
)
plot_mediation(med)
plot_mediation(med, show_estimates = FALSE)

}
