% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets.R
\docType{data}
\name{data_epilepsy}
\alias{data_epilepsy}
\title{Epilepsy Treatment and Seizure Counts}
\format{
A data frame with 236 observations and 9 variables:
\describe{
  \item{y}{Number of seizures in a 2-week period (count)}
  \item{trt}{Treatment group (factor): \code{placebo} or \code{progabide}}
  \item{base}{Seizure count during baseline period (numeric)}
  \item{age}{Age of patient (numeric)}
  \item{V4}{Indicator for 4th visit (binary)}
  \item{subject}{Patient ID (factor)}
  \item{period}{Follow-up period number (integer)}
  \item{lbase}{Log of baseline seizures (numeric)}
  \item{lage}{Log of age (numeric)}
}
}
\source{
\pkg{MASS} package. Original data from Thall and Vail (1990)
}
\usage{
data_epilepsy
}
\description{
RCT on the effect of a drug on the seizures in patients with epilepsy.
Contains repeated measures data with treatment groups,
baseline seizure counts, and follow-up counts.
}
\keyword{datasets}
