% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/helpers-strata.R
\name{.strata_pull_cols_uni}
\alias{.strata_pull_cols_uni}
\title{Pull (N, Effect, p) for a univariate stratum, aligned to a skeleton}
\usage{
.strata_pull_cols_uni(dlev, uni_res, skeleton, is_factor, exposures, outcome)
}
\description{
Pull (N, Effect, p) for a univariate stratum, aligned to a skeleton
}
\keyword{internal}
