% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/helpers-strata.R
\name{.strata_levels}
\alias{.strata_levels}
\title{Get ordered levels for a stratifier}
\usage{
.strata_levels(data, stratifier)
}
\description{
Get ordered levels for a stratifier
}
\keyword{internal}
